==> kdeclarative5-5.116.0-2-armv7h.pkg.tar.xz: usr/include/KF5/KDeclarative/calendarevents/calendarevents_export.h <==

#ifndef CALENDAREVENTS_EXPORT_H
#define CALENDAREVENTS_EXPORT_H

#ifdef CALENDAREVENTS_STATIC_DEFINE
#  define CALENDAREVENTS_EXPORT
#  define CALENDAREVENTS_NO_EXPORT
#else
#  ifndef CALENDAREVENTS_EXPORT
#    ifdef KF5CalendarEvents_EXPORTS
        /* We are building this library */
#      define CALENDAREVENTS_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define CALENDAREVENTS_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef CALENDAREVENTS_NO_EXPORT
#    define CALENDAREVENTS_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef CALENDAREVENTS_DECL_DEPRECATED
#  define CALENDAREVENTS_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef CALENDAREVENTS_DECL_DEPRECATED_EXPORT
#  define CALENDAREVENTS_DECL_DEPRECATED_EXPORT CALENDAREVENTS_EXPORT CALENDAREVENTS_DECL_DEPRECATED
#endif

#ifndef CALENDAREVENTS_DECL_DEPRECATED_NO_EXPORT
#  define CALENDAREVENTS_DECL_DEPRECATED_NO_EXPORT CALENDAREVENTS_NO_EXPORT CALENDAREVENTS_DECL_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef CALENDAREVENTS_NO_DEPRECATED
#    define CALENDAREVENTS_NO_DEPRECATED
#  endif
#endif

#define CALENDAREVENTS_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

/* Take any defaults from group settings */
#if !defined(CALENDAREVENTS_NO_DEPRECATED) && !defined(CALENDAREVENTS_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  ifdef KF_NO_DEPRECATED
#    define CALENDAREVENTS_NO_DEPRECATED
#  elif defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#    define CALENDAREVENTS_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  endif
#endif
#if !defined(CALENDAREVENTS_DISABLE_DEPRECATED_BEFORE_AND_AT) && defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  define CALENDAREVENTS_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#endif

#if !defined(CALENDAREVENTS_NO_DEPRECATED_WARNINGS) && !defined(CALENDAREVENTS_DEPRECATED_WARNINGS_SINCE)
#  ifdef KF_NO_DEPRECATED_WARNINGS
#    define CALENDAREVENTS_NO_DEPRECATED_WARNINGS
#  elif defined(KF_DEPRECATED_WARNINGS_SINCE)
#    define CALENDAREVENTS_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#  endif
#endif
#if !defined(CALENDAREVENTS_DEPRECATED_WARNINGS_SINCE) && defined(KF_DEPRECATED_WARNINGS_SINCE)
#  define CALENDAREVENTS_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#endif

#if defined(CALENDAREVENTS_NO_DEPRECATED)
#  undef CALENDAREVENTS_DEPRECATED
#  define CALENDAREVENTS_DEPRECATED_EXPORT CALENDAREVENTS_EXPORT
#  define CALENDAREVENTS_DEPRECATED_NO_EXPORT CALENDAREVENTS_NO_EXPORT
#elif defined(CALENDAREVENTS_NO_DEPRECATED_WARNINGS)
#  define CALENDAREVENTS_DEPRECATED
#  define CALENDAREVENTS_DEPRECATED_EXPORT CALENDAREVENTS_EXPORT
#  define CALENDAREVENTS_DEPRECATED_NO_EXPORT CALENDAREVENTS_NO_EXPORT
#else
#  define CALENDAREVENTS_DEPRECATED CALENDAREVENTS_DECL_DEPRECATED
#  define CALENDAREVENTS_DEPRECATED_EXPORT CALENDAREVENTS_DECL_DEPRECATED_EXPORT
#  define CALENDAREVENTS_DEPRECATED_NO_EXPORT CALENDAREVENTS_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define CALENDAREVENTS_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define CALENDAREVENTS_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef CALENDAREVENTS_NO_DEPRECATED
#  define CALENDAREVENTS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x57400
#endif
#ifdef CALENDAREVENTS_NO_DEPRECATED_WARNINGS
#  define CALENDAREVENTS_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef CALENDAREVENTS_DEPRECATED_WARNINGS_SINCE
#  ifdef CALENDAREVENTS_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define CALENDAREVENTS_DEPRECATED_WARNINGS_SINCE CALENDAREVENTS_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define CALENDAREVENTS_DEPRECATED_WARNINGS_SINCE 0x57400
#  endif
#endif

#ifndef CALENDAREVENTS_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define CALENDAREVENTS_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef CALENDAREVENTS_DEPRECATED
#  define CALENDAREVENTS_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > CALENDAREVENTS_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define CALENDAREVENTS_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#if CALENDAREVENTS_DEPRECATED_WARNINGS_SINCE >= 0x56a00
#  define CALENDAREVENTS_DEPRECATED_VERSION_5_106(text) CALENDAREVENTS_DECL_DEPRECATED_TEXT(text)
#else
#  define CALENDAREVENTS_DEPRECATED_VERSION_5_106(text)
#endif
#define CALENDAREVENTS_DEPRECATED_VERSION_5(minor, text)      CALENDAREVENTS_DEPRECATED_VERSION_5_##minor(text)
#define CALENDAREVENTS_DEPRECATED_VERSION(major, minor, text) CALENDAREVENTS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
#define CALENDAREVENTS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) CALENDAREVENTS_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
#  define CALENDAREVENTS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) CALENDAREVENTS_DEPRECATED_VERSION(major, minor, text)
#  define CALENDAREVENTS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) CALENDAREVENTS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#else
#  define CALENDAREVENTS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
#  define CALENDAREVENTS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#endif

#endif /* CALENDAREVENTS_EXPORT_H */

==> kdeclarative-5.106.0-1-armv7h.pkg.tar.xz: usr/include/KF5/KDeclarative/calendarevents/calendarevents_export.h <==

#ifndef CALENDAREVENTS_EXPORT_H
#define CALENDAREVENTS_EXPORT_H

#ifdef CALENDAREVENTS_STATIC_DEFINE
#  define CALENDAREVENTS_EXPORT
#  define CALENDAREVENTS_NO_EXPORT
#else
#  ifndef CALENDAREVENTS_EXPORT
#    ifdef KF5CalendarEvents_EXPORTS
        /* We are building this library */
#      define CALENDAREVENTS_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define CALENDAREVENTS_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef CALENDAREVENTS_NO_EXPORT
#    define CALENDAREVENTS_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef CALENDAREVENTS_DECL_DEPRECATED
#  define CALENDAREVENTS_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef CALENDAREVENTS_DECL_DEPRECATED_EXPORT
#  define CALENDAREVENTS_DECL_DEPRECATED_EXPORT CALENDAREVENTS_EXPORT CALENDAREVENTS_DECL_DEPRECATED
#endif

#ifndef CALENDAREVENTS_DECL_DEPRECATED_NO_EXPORT
#  define CALENDAREVENTS_DECL_DEPRECATED_NO_EXPORT CALENDAREVENTS_NO_EXPORT CALENDAREVENTS_DECL_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef CALENDAREVENTS_NO_DEPRECATED
#    define CALENDAREVENTS_NO_DEPRECATED
#  endif
#endif

#define CALENDAREVENTS_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

/* Take any defaults from group settings */
#if !defined(CALENDAREVENTS_NO_DEPRECATED) && !defined(CALENDAREVENTS_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  ifdef KF_NO_DEPRECATED
#    define CALENDAREVENTS_NO_DEPRECATED
#  elif defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#    define CALENDAREVENTS_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  endif
#endif
#if !defined(CALENDAREVENTS_DISABLE_DEPRECATED_BEFORE_AND_AT) && defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  define CALENDAREVENTS_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#endif

#if !defined(CALENDAREVENTS_NO_DEPRECATED_WARNINGS) && !defined(CALENDAREVENTS_DEPRECATED_WARNINGS_SINCE)
#  ifdef KF_NO_DEPRECATED_WARNINGS
#    define CALENDAREVENTS_NO_DEPRECATED_WARNINGS
#  elif defined(KF_DEPRECATED_WARNINGS_SINCE)
#    define CALENDAREVENTS_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#  endif
#endif
#if !defined(CALENDAREVENTS_DEPRECATED_WARNINGS_SINCE) && defined(KF_DEPRECATED_WARNINGS_SINCE)
#  define CALENDAREVENTS_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#endif

#if defined(CALENDAREVENTS_NO_DEPRECATED)
#  undef CALENDAREVENTS_DEPRECATED
#  define CALENDAREVENTS_DEPRECATED_EXPORT CALENDAREVENTS_EXPORT
#  define CALENDAREVENTS_DEPRECATED_NO_EXPORT CALENDAREVENTS_NO_EXPORT
#elif defined(CALENDAREVENTS_NO_DEPRECATED_WARNINGS)
#  define CALENDAREVENTS_DEPRECATED
#  define CALENDAREVENTS_DEPRECATED_EXPORT CALENDAREVENTS_EXPORT
#  define CALENDAREVENTS_DEPRECATED_NO_EXPORT CALENDAREVENTS_NO_EXPORT
#else
#  define CALENDAREVENTS_DEPRECATED CALENDAREVENTS_DECL_DEPRECATED
#  define CALENDAREVENTS_DEPRECATED_EXPORT CALENDAREVENTS_DECL_DEPRECATED_EXPORT
#  define CALENDAREVENTS_DEPRECATED_NO_EXPORT CALENDAREVENTS_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define CALENDAREVENTS_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define CALENDAREVENTS_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef CALENDAREVENTS_NO_DEPRECATED
#  define CALENDAREVENTS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56a00
#endif
#ifdef CALENDAREVENTS_NO_DEPRECATED_WARNINGS
#  define CALENDAREVENTS_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef CALENDAREVENTS_DEPRECATED_WARNINGS_SINCE
#  ifdef CALENDAREVENTS_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define CALENDAREVENTS_DEPRECATED_WARNINGS_SINCE CALENDAREVENTS_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define CALENDAREVENTS_DEPRECATED_WARNINGS_SINCE 0x56a00
#  endif
#endif

#ifndef CALENDAREVENTS_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define CALENDAREVENTS_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef CALENDAREVENTS_DEPRECATED
#  define CALENDAREVENTS_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > CALENDAREVENTS_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define CALENDAREVENTS_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#if CALENDAREVENTS_DEPRECATED_WARNINGS_SINCE >= 0x56a00
#  define CALENDAREVENTS_DEPRECATED_VERSION_5_106(text) CALENDAREVENTS_DECL_DEPRECATED_TEXT(text)
#else
#  define CALENDAREVENTS_DEPRECATED_VERSION_5_106(text)
#endif
#define CALENDAREVENTS_DEPRECATED_VERSION_5(minor, text)      CALENDAREVENTS_DEPRECATED_VERSION_5_##minor(text)
#define CALENDAREVENTS_DEPRECATED_VERSION(major, minor, text) CALENDAREVENTS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
#define CALENDAREVENTS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) CALENDAREVENTS_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
#  define CALENDAREVENTS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) CALENDAREVENTS_DEPRECATED_VERSION(major, minor, text)
#  define CALENDAREVENTS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) CALENDAREVENTS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#else
#  define CALENDAREVENTS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
#  define CALENDAREVENTS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#endif

#endif /* CALENDAREVENTS_EXPORT_H */
